==> kubernetes-model-gatewayapi-6.4.0-sources.jar: io/fabric8/kubernetes/api/model/gatewayapi/v1alpha2/TLSRouteSpecFluent.java <==
package io.fabric8.kubernetes.api.model.gatewayapi.v1alpha2;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface TLSRouteSpecFluent<A extends TLSRouteSpecFluent<A>> extends Fluent<A>{
  public A addToHostnames(Integer index,String item);
  public A setToHostnames(Integer index,String item);
  public A addToHostnames(java.lang.String... items);
  public A addAllToHostnames(Collection<String> items);
  public A removeFromHostnames(java.lang.String... items);
  public A removeAllFromHostnames(Collection<String> items);
  public List<String> getHostnames();
  public String getHostname(Integer index);
  public String getFirstHostname();
  public String getLastHostname();
  public String getMatchingHostname(Predicate<String> predicate);
  public Boolean hasMatchingHostname(Predicate<String> predicate);
  public A withHostnames(List<String> hostnames);
  public A withHostnames(java.lang.String... hostnames);
  public Boolean hasHostnames();
  public A addToParentRefs(Integer index,ParentReference item);
  public A setToParentRefs(Integer index,ParentReference item);
  public A addToParentRefs(io.fabric8.kubernetes.api.model.gatewayapi.v1alpha2.ParentReference... items);
  public A addAllToParentRefs(Collection<ParentReference> items);
  public A removeFromParentRefs(io.fabric8.kubernetes.api.model.gatewayapi.v1alpha2.ParentReference... items);
  public A removeAllFromParentRefs(Collection<ParentReference> items);
  public A removeMatchingFromParentRefs(Predicate<ParentReferenceBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildParentRefs instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<ParentReference> getParentRefs();
  public List<ParentReference> buildParentRefs();
  public ParentReference buildParentRef(Integer index);
  public ParentReference buildFirstParentRef();
  public ParentReference buildLastParentRef();
  public ParentReference buildMatchingParentRef(Predicate<ParentReferenceBuilder> predicate);
  public Boolean hasMatchingParentRef(Predicate<ParentReferenceBuilder> predicate);
  public A withParentRefs(List<ParentReference> parentRefs);
  public A withParentRefs(io.fabric8.kubernetes.api.model.gatewayapi.v1alpha2.ParentReference... parentRefs);
  public Boolean hasParentRefs();
  public TLSRouteSpecFluent.ParentRefsNested<A> addNewParentRef();
  public TLSRouteSpecFluent.ParentRefsNested<A> addNewParentRefLike(ParentReference item);
  public TLSRouteSpecFluent.ParentRefsNested<A> setNewParentRefLike(Integer index,ParentReference item);
  public TLSRouteSpecFluent.ParentRefsNested<A> editParentRef(Integer index);
  public TLSRouteSpecFluent.ParentRefsNested<A> editFirstParentRef();
  public TLSRouteSpecFluent.ParentRefsNested<A> editLastParentRef();
  public TLSRouteSpecFluent.ParentRefsNested<A> editMatchingParentRef(Predicate<ParentReferenceBuilder> predicate);
  public A addToRules(Integer index,TLSRouteRule item);
  public A setToRules(Integer index,TLSRouteRule item);
  public A addToRules(io.fabric8.kubernetes.api.model.gatewayapi.v1alpha2.TLSRouteRule... items);
  public A addAllToRules(Collection<TLSRouteRule> items);
  public A removeFromRules(io.fabric8.kubernetes.api.model.gatewayapi.v1alpha2.TLSRouteRule... items);
  public A removeAllFromRules(Collection<TLSRouteRule> items);
  public A removeMatchingFromRules(Predicate<TLSRouteRuleBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildRules instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<TLSRouteRule> getRules();
  public List<TLSRouteRule> buildRules();
  public TLSRouteRule buildRule(Integer index);
  public TLSRouteRule buildFirstRule();
  public TLSRouteRule buildLastRule();
  public TLSRouteRule buildMatchingRule(Predicate<TLSRouteRuleBuilder> predicate);
  public Boolean hasMatchingRule(Predicate<TLSRouteRuleBuilder> predicate);
  public A withRules(List<TLSRouteRule> rules);
  public A withRules(io.fabric8.kubernetes.api.model.gatewayapi.v1alpha2.TLSRouteRule... rules);
  public Boolean hasRules();
  public TLSRouteSpecFluent.RulesNested<A> addNewRule();
  public TLSRouteSpecFluent.RulesNested<A> addNewRuleLike(TLSRouteRule item);
  public TLSRouteSpecFluent.RulesNested<A> setNewRuleLike(Integer index,TLSRouteRule item);
  public TLSRouteSpecFluent.RulesNested<A> editRule(Integer index);
  public TLSRouteSpecFluent.RulesNested<A> editFirstRule();
  public TLSRouteSpecFluent.RulesNested<A> editLastRule();
  public TLSRouteSpecFluent.RulesNested<A> editMatchingRule(Predicate<TLSRouteRuleBuilder> predicate);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface ParentRefsNested<N> extends Nested<N>,ParentReferenceFluent<TLSRouteSpecFluent.ParentRefsNested<N>>{
    public N and();
    public N endParentRef();
    
  }
  public interface RulesNested<N> extends Nested<N>,TLSRouteRuleFluent<TLSRouteSpecFluent.RulesNested<N>>{
    public N and();
    public N endRule();
    
  }
  
}

==> kubernetes-model-gatewayapi-6.5.1-sources.jar: io/fabric8/kubernetes/api/model/gatewayapi/v1alpha2/TLSRouteSpecFluent.java <==
package io.fabric8.kubernetes.api.model.gatewayapi.v1alpha2;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.model.gatewayapi.v1beta1.ParentReference;
import io.fabric8.kubernetes.api.model.gatewayapi.v1beta1.ParentReferenceBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import io.fabric8.kubernetes.api.model.gatewayapi.v1beta1.ParentReferenceFluent;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface TLSRouteSpecFluent<A extends TLSRouteSpecFluent<A>> extends Fluent<A>{
  public A addToHostnames(Integer index,String item);
  public A setToHostnames(Integer index,String item);
  public A addToHostnames(java.lang.String... items);
  public A addAllToHostnames(Collection<String> items);
  public A removeFromHostnames(java.lang.String... items);
  public A removeAllFromHostnames(Collection<String> items);
  public List<String> getHostnames();
  public String getHostname(Integer index);
  public String getFirstHostname();
  public String getLastHostname();
  public String getMatchingHostname(Predicate<String> predicate);
  public Boolean hasMatchingHostname(Predicate<String> predicate);
  public A withHostnames(List<String> hostnames);
  public A withHostnames(java.lang.String... hostnames);
  public Boolean hasHostnames();
  public A addToParentRefs(Integer index,ParentReference item);
  public A setToParentRefs(Integer index,ParentReference item);
  public A addToParentRefs(io.fabric8.kubernetes.api.model.gatewayapi.v1beta1.ParentReference... items);
  public A addAllToParentRefs(Collection<ParentReference> items);
  public A removeFromParentRefs(io.fabric8.kubernetes.api.model.gatewayapi.v1beta1.ParentReference... items);
  public A removeAllFromParentRefs(Collection<ParentReference> items);
  public A removeMatchingFromParentRefs(Predicate<ParentReferenceBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildParentRefs instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<ParentReference> getParentRefs();
  public List<ParentReference> buildParentRefs();
  public ParentReference buildParentRef(Integer index);
  public ParentReference buildFirstParentRef();
  public ParentReference buildLastParentRef();
  public ParentReference buildMatchingParentRef(Predicate<ParentReferenceBuilder> predicate);
  public Boolean hasMatchingParentRef(Predicate<ParentReferenceBuilder> predicate);
  public A withParentRefs(List<ParentReference> parentRefs);
  public A withParentRefs(io.fabric8.kubernetes.api.model.gatewayapi.v1beta1.ParentReference... parentRefs);
  public Boolean hasParentRefs();
  public TLSRouteSpecFluent.ParentRefsNested<A> addNewParentRef();
  public TLSRouteSpecFluent.ParentRefsNested<A> addNewParentRefLike(ParentReference item);
  public TLSRouteSpecFluent.ParentRefsNested<A> setNewParentRefLike(Integer index,ParentReference item);
  public TLSRouteSpecFluent.ParentRefsNested<A> editParentRef(Integer index);
  public TLSRouteSpecFluent.ParentRefsNested<A> editFirstParentRef();
  public TLSRouteSpecFluent.ParentRefsNested<A> editLastParentRef();
  public TLSRouteSpecFluent.ParentRefsNested<A> editMatchingParentRef(Predicate<ParentReferenceBuilder> predicate);
  public A addToRules(Integer index,TLSRouteRule item);
  public A setToRules(Integer index,TLSRouteRule item);
  public A addToRules(io.fabric8.kubernetes.api.model.gatewayapi.v1alpha2.TLSRouteRule... items);
  public A addAllToRules(Collection<TLSRouteRule> items);
  public A removeFromRules(io.fabric8.kubernetes.api.model.gatewayapi.v1alpha2.TLSRouteRule... items);
  public A removeAllFromRules(Collection<TLSRouteRule> items);
  public A removeMatchingFromRules(Predicate<TLSRouteRuleBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildRules instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<TLSRouteRule> getRules();
  public List<TLSRouteRule> buildRules();
  public TLSRouteRule buildRule(Integer index);
  public TLSRouteRule buildFirstRule();
  public TLSRouteRule buildLastRule();
  public TLSRouteRule buildMatchingRule(Predicate<TLSRouteRuleBuilder> predicate);
  public Boolean hasMatchingRule(Predicate<TLSRouteRuleBuilder> predicate);
  public A withRules(List<TLSRouteRule> rules);
  public A withRules(io.fabric8.kubernetes.api.model.gatewayapi.v1alpha2.TLSRouteRule... rules);
  public Boolean hasRules();
  public TLSRouteSpecFluent.RulesNested<A> addNewRule();
  public TLSRouteSpecFluent.RulesNested<A> addNewRuleLike(TLSRouteRule item);
  public TLSRouteSpecFluent.RulesNested<A> setNewRuleLike(Integer index,TLSRouteRule item);
  public TLSRouteSpecFluent.RulesNested<A> editRule(Integer index);
  public TLSRouteSpecFluent.RulesNested<A> editFirstRule();
  public TLSRouteSpecFluent.RulesNested<A> editLastRule();
  public TLSRouteSpecFluent.RulesNested<A> editMatchingRule(Predicate<TLSRouteRuleBuilder> predicate);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface ParentRefsNested<N> extends Nested<N>,ParentReferenceFluent<TLSRouteSpecFluent.ParentRefsNested<N>>{
    public N and();
    public N endParentRef();
    
  }
  public interface RulesNested<N> extends Nested<N>,TLSRouteRuleFluent<TLSRouteSpecFluent.RulesNested<N>>{
    public N and();
    public N endRule();
    
  }
  
}
